**PLUGINS**
===========

EXODUS
------
Train fast. Why wait?

Sinabs-DynapCNN
---------------
Deploy your model to state-of-the-art neuromrophic hardware. Documentation `available here. <https://synsense.gitlab.io/sinabs-dynapcnn/>`_